@@ -47,6 +47,7 @@ class QSessionManager;
 using BaseApplication = QCoreApplication;
 #endif // DISABLE_GUI
 
+#include "base/settingvalue.h"
 #include "base/types.h"
 #include "cmdoptions.h"
 
@@ -59,7 +60,7 @@ class FileLogger;
 
 namespace BitTorrent
 {
-    class TorrentHandle;
+    class Torrent;
 }
 
 namespace RSS
@@ -71,7 +72,7 @@ namespace RSS
 class Application final : public BaseApplication
 {
     Q_OBJECT
-    Q_DISABLE_COPY(Application)
+    Q_DISABLE_COPY_MOVE(Application)
 
 public:
     Application(int &argc, char **argv);
@@ -87,6 +88,11 @@ public:
 
     const QBtCommandLineParameters &commandLineArgs() const;
 
+#ifdef Q_OS_WIN
+    int memoryWorkingSetLimit() const;
+    void setMemoryWorkingSetLimit(int size);
+#endif
+
     // FileLogger properties
     bool isFileLoggerEnabled() const;
     void setFileLoggerEnabled(bool value);
@@ -112,7 +118,7 @@ protected:
 
 private slots:
     void processMessage(const QString &message);
-    void torrentFinished(BitTorrent::TorrentHandle *const torrent);
+    void torrentFinished(BitTorrent::Torrent *const torrent);
     void allTorrentsFinished();
     void cleanup();
 #if (!defined(DISABLE_GUI) && defined(Q_OS_WIN))
@@ -120,6 +126,14 @@ private slots:
 #endif
 
 private:
+#if (defined(Q_OS_WIN) && defined(QBT_USES_LIBTORRENT2))
+    void applyMemoryWorkingSetLimit();
+#endif
+    void initializeTranslation();
+    void processParams(const QStringList &params);
+    void runExternalProgram(const BitTorrent::Torrent *torrent) const;
+    void sendNotificationEmail(const BitTorrent::Torrent *torrent);
+
     ApplicationInstanceManager *m_instanceManager = nullptr;
     bool m_running;
     ShutdownDialogAction m_shutdownAct;
@@ -140,8 +154,14 @@ private:
     QTranslator m_translator;
     QStringList m_paramsQueue;
 
-    void initializeTranslation();
-    void processParams(const QStringList &params);
-    void runExternalProgram(const BitTorrent::TorrentHandle *torrent) const;
-    void sendNotificationEmail(const BitTorrent::TorrentHandle *torrent);
+#ifdef Q_OS_WIN
+    SettingValue<int> m_storeMemoryWorkingSetLimit;
+#endif
+    SettingValue<bool> m_storeFileLoggerEnabled;
+    SettingValue<bool> m_storeFileLoggerBackup;
+    SettingValue<bool> m_storeFileLoggerDeleteOld;
+    SettingValue<int> m_storeFileLoggerMaxSize;
+    SettingValue<int> m_storeFileLoggerAge;
+    SettingValue<int> m_storeFileLoggerAgeType;
+    SettingValue<QString> m_storeFileLoggerPath;
 };
