@@ -29,10 +29,11 @@
 
 #pragma once
 
+#include <QtContainerFwd>
 #include <QMetaType>
 #include <QString>
-#include <QtContainerFwd>
 
+#include "base/3rdparty/expected.hpp"
 #include "base/tagset.h"
 #include "abstractfilestorage.h"
 
@@ -294,6 +295,7 @@ namespace BitTorrent
         virtual void clearPeers() = 0;
 
         virtual QString createMagnetURI() const = 0;
+        virtual nonstd::expected<void, QString> exportToFile(const QString &path) const = 0;
 
         TorrentID id() const;
         bool isResumed() const;
