@@ -44,7 +44,7 @@
 #include "base/global.h"
 #include "base/logger.h"
 #include "base/preferences.h"
-#include "private/downloadhandlerimpl.h"
+#include "downloadhandlerimpl.h"
 #include "proxyconfigurationmanager.h"
 
 namespace
@@ -60,7 +60,8 @@ namespace
         {
             const QDateTime now = QDateTime::currentDateTime();
             QList<QNetworkCookie> cookies = Preferences::instance()->getNetworkCookies();
-            for (const QNetworkCookie &cookie : asConst(Preferences::instance()->getNetworkCookies())) {
+            for (const QNetworkCookie &cookie : asConst(Preferences::instance()->getNetworkCookies()))
+            {
                 if (cookie.isSessionCookie() || (cookie.expirationDate() <= now))
                     cookies.removeAll(cookie);
             }
@@ -72,7 +73,8 @@ namespace
         {
             const QDateTime now = QDateTime::currentDateTime();
             QList<QNetworkCookie> cookies = allCookies();
-            for (const QNetworkCookie &cookie : asConst(allCookies())) {
+            for (const QNetworkCookie &cookie : asConst(allCookies()))
+            {
                 if (cookie.isSessionCookie() || (cookie.expirationDate() <= now))
                     cookies.removeAll(cookie);
             }
@@ -87,7 +89,8 @@ namespace
         {
             const QDateTime now = QDateTime::currentDateTime();
             QList<QNetworkCookie> cookies = QNetworkCookieJar::cookiesForUrl(url);
-            for (const QNetworkCookie &cookie : asConst(QNetworkCookieJar::cookiesForUrl(url))) {
+            for (const QNetworkCookie &cookie : asConst(QNetworkCookieJar::cookiesForUrl(url)))
+            {
                 if (!cookie.isSessionCookie() && (cookie.expirationDate() <= now))
                     cookies.removeAll(cookie);
             }
@@ -99,7 +102,8 @@ namespace
         {
             const QDateTime now = QDateTime::currentDateTime();
             QList<QNetworkCookie> cookies = cookieList;
-            for (const QNetworkCookie &cookie : cookieList) {
+            for (const QNetworkCookie &cookie : cookieList)
+            {
                 if (!cookie.isSessionCookie() && (cookie.expirationDate() <= now))
                     cookies.removeAll(cookie);
             }
@@ -119,8 +123,12 @@ namespace
 
         // Spoof HTTP Referer to allow adding torrent link from Torcache/KickAssTorrents
         request.setRawHeader("Referer", request.url().toEncoded().data());
-        // Accept gzip
+#ifdef QT_NO_COMPRESS
+        // The macro "QT_NO_COMPRESS" defined in QT will disable the zlib releated features
+        // and reply data auto-decompression in QT will also be disabled. But we can support
+        // gzip encoding and manually decompress the reply data.
         request.setRawHeader("Accept-Encoding", "gzip");
+#endif
         // Qt doesn't support Magnet protocol so we need to handle redirections manually
         request.setAttribute(QNetworkRequest::RedirectPolicyAttribute, QNetworkRequest::ManualRedirectPolicy);
 
@@ -172,10 +180,12 @@ Net::DownloadHandler *Net::DownloadManager::download(const DownloadRequest &down
         m_waitingJobs[id].removeOne(downloadHandler);
     });
 
-    if (isSequentialService && m_busyServices.contains(id)) {
+    if (isSequentialService && m_busyServices.contains(id))
+    {
         m_waitingJobs[id].enqueue(downloadHandler);
     }
-    else {
+    else
+    {
         qDebug("Downloading %s...", qUtf8Printable(downloadRequest.url()));
         if (isSequentialService)
             m_busyServices.insert(id);
@@ -230,27 +240,32 @@ void Net::DownloadManager::applyProxySettings()
     const ProxyConfiguration proxyConfig = proxyManager->proxyConfiguration();
     QNetworkProxy proxy;
 
-    if (!proxyManager->isProxyOnlyForTorrents() && (proxyConfig.type != ProxyType::None)) {
+    if (!proxyManager->isProxyOnlyForTorrents() && (proxyConfig.type != ProxyType::None))
+    {
         // Proxy enabled
         proxy.setHostName(proxyConfig.ip);
         proxy.setPort(proxyConfig.port);
         // Default proxy type is HTTP, we must change if it is SOCKS5
-        if ((proxyConfig.type == ProxyType::SOCKS5) || (proxyConfig.type == ProxyType::SOCKS5_PW)) {
+        if ((proxyConfig.type == ProxyType::SOCKS5) || (proxyConfig.type == ProxyType::SOCKS5_PW))
+        {
             qDebug() << Q_FUNC_INFO << "using SOCKS proxy";
             proxy.setType(QNetworkProxy::Socks5Proxy);
         }
-        else {
+        else
+        {
             qDebug() << Q_FUNC_INFO << "using HTTP proxy";
             proxy.setType(QNetworkProxy::HttpProxy);
         }
         // Authentication?
-        if (proxyManager->isAuthenticationRequired()) {
+        if (proxyManager->isAuthenticationRequired())
+        {
             qDebug("Proxy requires authentication, authenticating...");
             proxy.setUser(proxyConfig.username);
             proxy.setPassword(proxyConfig.password);
         }
     }
-    else {
+    else
+    {
         proxy.setType(QNetworkProxy::NoProxy);
     }
 
@@ -264,7 +279,8 @@ void Net::DownloadManager::handleReplyFinished(const QNetworkReply *reply)
     // in the case when the redirection occurred.
     const ServiceID id = ServiceID::fromURL(reply->request().url());
     const auto waitingJobsIter = m_waitingJobs.find(id);
-    if ((waitingJobsIter == m_waitingJobs.end()) || waitingJobsIter.value().isEmpty()) {
+    if ((waitingJobsIter == m_waitingJobs.end()) || waitingJobsIter.value().isEmpty())
+    {
         // No more waiting jobs for given ServiceID
         m_busyServices.remove(id);
         return;
@@ -336,6 +352,17 @@ Net::DownloadRequest &Net::DownloadRequest::saveToFile(const bool value)
     return *this;
 }
 
+QString Net::DownloadRequest::destFileName() const
+{
+    return m_destFileName;
+}
+
+Net::DownloadRequest &Net::DownloadRequest::destFileName(const QString &value)
+{
+    m_destFileName = value;
+    return *this;
+}
+
 Net::ServiceID Net::ServiceID::fromURL(const QUrl &url)
 {
     return {url.host(), url.port(80)};
