@@ -71,6 +71,7 @@ SearchJobWidget::SearchJobWidget(SearchHandler *searchHandler, QWidget *parent)
     loadSettings();
 
     header()->setStretchLastSection(false);
+    header()->setTextElideMode(Qt::ElideRight);
 
     // Set Search results list model
     m_searchListModel = new QStandardItemModel(0, SearchSortModel::NB_SEARCH_COLUMNS, this);
@@ -210,11 +211,11 @@ void SearchJobWidget::cancelSearch()
     m_searchHandler->cancelSearch();
 }
 
-void SearchJobWidget::downloadTorrents()
+void SearchJobWidget::downloadTorrents(const AddTorrentOption option)
 {
     const QModelIndexList rows {m_ui->resultsBrowser->selectionModel()->selectedRows()};
     for (const QModelIndex &rowIndex : rows)
-        downloadTorrent(rowIndex);
+        downloadTorrent(rowIndex, option);
 }
 
 void SearchJobWidget::openTorrentPages() const
@@ -270,7 +271,7 @@ void SearchJobWidget::setStatus(Status value)
     emit statusChanged();
 }
 
-void SearchJobWidget::downloadTorrent(const QModelIndex &rowIndex)
+void SearchJobWidget::downloadTorrent(const QModelIndex &rowIndex, const AddTorrentOption option)
 {
     const QString torrentUrl = m_proxyModel->data(
                 m_proxyModel->index(rowIndex.row(), SearchSortModel::DL_LINK)).toString();
@@ -279,22 +280,23 @@ void SearchJobWidget::downloadTorrent(const QModelIndex &rowIndex)
 
     if (torrentUrl.startsWith("magnet:", Qt::CaseInsensitive))
     {
-        addTorrentToSession(torrentUrl);
+        addTorrentToSession(torrentUrl, option);
     }
     else
     {
         SearchDownloadHandler *downloadHandler = m_searchHandler->manager()->downloadTorrent(siteUrl, torrentUrl);
-        connect(downloadHandler, &SearchDownloadHandler::downloadFinished, this, &SearchJobWidget::addTorrentToSession);
+        connect(downloadHandler, &SearchDownloadHandler::downloadFinished
+            , this, [this, option](const QString &source) { addTorrentToSession(source, option); });
         connect(downloadHandler, &SearchDownloadHandler::downloadFinished, downloadHandler, &SearchDownloadHandler::deleteLater);
     }
     setRowColor(rowIndex.row(), QApplication::palette().color(QPalette::LinkVisited));
 }
 
-void SearchJobWidget::addTorrentToSession(const QString &source)
+void SearchJobWidget::addTorrentToSession(const QString &source, const AddTorrentOption option)
 {
     if (source.isEmpty()) return;
 
-    if (AddNewTorrentDialog::isEnabled())
+    if ((option == AddTorrentOption::ShowDialog) || ((option == AddTorrentOption::Default) && AddNewTorrentDialog::isEnabled()))
         AddNewTorrentDialog::show(source, this);
     else
         BitTorrent::Session::instance()->addTorrent(source);
@@ -365,9 +367,9 @@ void SearchJobWidget::fillFilterComboBoxes()
 
 void SearchJobWidget::filterSearchResults(const QString &name)
 {
-    const QRegExp::PatternSyntax patternSyntax = Preferences::instance()->getRegexAsFilteringPatternForSearchJob()
-                    ? QRegExp::RegExp : QRegExp::WildcardUnix;
-    m_proxyModel->setFilterRegExp(QRegExp(name, Qt::CaseInsensitive, patternSyntax));
+    const QString pattern = (Preferences::instance()->getRegexAsFilteringPatternForSearchJob()
+                    ? name : Utils::String::wildcardToRegexPattern(name));
+    m_proxyModel->setFilterRegularExpression(QRegularExpression(pattern, QRegularExpression::CaseInsensitiveOption));
     updateResultsCount();
 }
 
@@ -393,31 +395,23 @@ void SearchJobWidget::contextMenuEvent(QContextMenuEvent *event)
     auto *menu = new QMenu(this);
     menu->setAttribute(Qt::WA_DeleteOnClose);
 
-    const QAction *downloadAction = menu->addAction(
-        UIThemeManager::instance()->getIcon("download"), tr("Download"));
-    connect(downloadAction, &QAction::triggered, this, &SearchJobWidget::downloadTorrents);
-
+    menu->addAction(UIThemeManager::instance()->getIcon("download"), tr("Open download window")
+        , this, [this]() { downloadTorrents(AddTorrentOption::ShowDialog); });
+    menu->addAction(UIThemeManager::instance()->getIcon("download"), tr("Download")
+        , this, [this]() { downloadTorrents(AddTorrentOption::SkipDialog); });
     menu->addSeparator();
-
-    const QAction *openDescriptionAction = menu->addAction(
-        UIThemeManager::instance()->getIcon("application-x-mswinurl"), tr("Open description page"));
-    connect(openDescriptionAction, &QAction::triggered, this, &SearchJobWidget::openTorrentPages);
+    menu->addAction(UIThemeManager::instance()->getIcon("application-x-mswinurl"), tr("Open description page")
+        , this, &SearchJobWidget::openTorrentPages);
 
     QMenu *copySubMenu = menu->addMenu(
         UIThemeManager::instance()->getIcon("edit-copy"), tr("Copy"));
 
-    const QAction *copyNamesAction = copySubMenu->addAction(
-        UIThemeManager::instance()->getIcon("edit-copy"), tr("Name"));
-    connect(copyNamesAction, &QAction::triggered, this, &SearchJobWidget::copyTorrentNames);
-
-    const QAction *copyDownloadLinkAction = copySubMenu->addAction(
-        UIThemeManager::instance()->getIcon("edit-copy"), tr("Download link"));
-    connect(copyDownloadLinkAction, &QAction::triggered
+    copySubMenu->addAction(UIThemeManager::instance()->getIcon("edit-copy"), tr("Name")
+        , this, &SearchJobWidget::copyTorrentNames);
+    copySubMenu->addAction(UIThemeManager::instance()->getIcon("edit-copy"), tr("Download link")
         , this, &SearchJobWidget::copyTorrentDownloadLinks);
-
-    const QAction *copyDescriptionAction = copySubMenu->addAction(
-        UIThemeManager::instance()->getIcon("edit-copy"), tr("Description page URL"));
-    connect(copyDescriptionAction, &QAction::triggered, this, &SearchJobWidget::copyTorrentURLs);
+    copySubMenu->addAction(UIThemeManager::instance()->getIcon("edit-copy"), tr("Description page URL")
+        , this, &SearchJobWidget::copyTorrentURLs);
 
     menu->popup(event->globalPos());
 }
