@@ -26,12 +26,13 @@
  * exception statement from your version.
  */
 
-#ifndef SEARCHSORTMODEL_H
-#define SEARCHSORTMODEL_H
+#pragma once
 
 #include <QSortFilterProxyModel>
 #include <QStringList>
 
+#include "base/utils/compare.h"
+
 class SearchSortModel final : public QSortFilterProxyModel
 {
     using base = QSortFilterProxyModel;
@@ -49,6 +50,11 @@ public:
         NB_SEARCH_COLUMNS
     };
 
+    enum SearchDataRole
+    {
+        UnderlyingDataRole = Qt::UserRole
+    };
+
     explicit SearchSortModel(QObject *parent = nullptr);
 
     void enableNameFilter(bool enabled);
@@ -90,6 +96,6 @@ private:
     int m_minSeeds, m_maxSeeds;
     int m_minLeeches, m_maxLeeches;
     qint64 m_minSize, m_maxSize;
-};
 
-#endif // SEARCHSORTMODEL_H
+    Utils::Compare::NaturalLessThan<Qt::CaseInsensitive> m_naturalLessThan;
+};
